<template>
	<div class="app-container">
		<div class="search_form">
			<div>
				<span class="search_title">客户名称：</span>
				<el-input
					v-model="searchForm.customerName"
					style="width: 240px"
					placeholder="请输入"
					@change="handleQuery"
					clearable
					prefix-icon="Search"
				/>
				<span class="search_title ml10">项目名称：</span>
				<el-input
					v-model="searchForm.projectName"
					style="width: 240px"
					placeholder="请输入"
					@change="handleQuery"
					clearable
					prefix-icon="Search"
				/>
				<span class="search_title ml10">录入日期：</span>
				<el-date-picker v-model="searchForm.entryDate" value-format="YYYY-MM-DD" format="YYYY-MM-DD" type="daterange"
												placeholder="请选择" clearable @change="changeDaterange" />
				<el-button type="primary" @click="handleQuery" style="margin-left: 10px"
				>搜索</el-button
				>
			</div>
			<div>
				<el-button @click="handleOut">导出</el-button>
			</div>
		</div>
		<div class="table_list">
			<PIMTable
				rowKey="id"
				:column="tableColumn"
				:tableData="tableData"
				:page="page"
				:tableLoading="tableLoading"
				@pagination="pagination"
			></PIMTable>
		</div>
	</div>
</template>

<script setup>
import {onMounted, ref} from "vue";
import { ElMessageBox } from "element-plus";
import dayjs from "dayjs";
import {schedulingListPage} from "@/api/productionManagement/productionOrder.js";
const { proxy } = getCurrentInstance();

const tableColumn = ref([
	{
		label: "录入日期",
		prop: "entryDate",
		width: 120,
	},
	{
		label: "合同号",
		prop: "salesContractNo",
		width: 220,
	},
	{
		label: "客户合同号",
		prop: "customerContractNo",
		width: 250,
	},
	{
		label: "客户名称",
		prop: "customerName",
		width: 250,
	},
	{
		label: "项目名称",
		prop: "projectName",
		width:300
	},
	{
		label: "产品大类",
		prop: "productCategory",
		width: 160,
	},
	{
		label: "规格型号",
		prop: "specificationModel",
		width: 220,
	},
	{
		label: "单位",
		prop: "unit",
		width:90
	},
	{
		label: "数量",
		prop: "quantity",
	},
	{
		label: "排产数量",
		prop: "schedulingNum",
		width: 100,
	},
	{
		label: "完工数量",
		prop: "successNum",
		width: 100,
	},
]);
const tableData = ref([]);
const tableLoading = ref(false);
const page = reactive({
	current: 1,
	size: 100,
	total: 0,
});

const data = reactive({
	searchForm: {
		customerName: "",
		projectName: "",
		entryDate: [], // 录入日期
		entryDateStart: '',
		entryDateEnd: '',
	},
});
const { searchForm } = toRefs(data);

// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
	page.current = 1;
	getList();
};
const pagination = (obj) => {
	page.current = obj.page;
	page.size = obj.limit;
	getList();
};
const changeDaterange = (value) => {
	if (value) {
		searchForm.value.entryDateStart = value[0];
		searchForm.value.entryDateEnd = value[1];
	} else {
		searchForm.value.entryDateStart = undefined;
		searchForm.value.entryDateEnd = undefined;
	}
	handleQuery();
};
const getList = () => {
	tableLoading.value = true;
	// 构造一个新的对象，不包含entryDate字段
	const params = { ...searchForm.value, ...page };
	params.entryDate = undefined
	schedulingListPage(params).then((res) => {
		tableLoading.value = false;
		tableData.value = res.data.records;
		page.total = res.data.total;
	}).catch(() => {
		tableLoading.value = false;
	})
};

// 导出
const handleOut = () => {
	ElMessageBox.confirm("选中的内容将被导出，是否确认导出？", "导出", {
		confirmButtonText: "确认",
		cancelButtonText: "取消",
		type: "warning",
	})
		.then(() => {
			proxy.download("/salesLedger/scheduling/export", {}, "生产订单.xlsx");
		})
		.catch(() => {
			proxy.$modal.msg("已取消");
		});
};

onMounted(() => {
	searchForm.value.entryDate = [
		dayjs().format("YYYY-MM-DD"),
		dayjs().add(1, "day").format("YYYY-MM-DD"),
	]
	searchForm.value.entryDateStart = dayjs().format("YYYY-MM-DD")
	searchForm.value.entryDateEnd = dayjs().add(1, "day").format("YYYY-MM-DD")
	getList();
});
</script>

<style scoped lang="scss"></style>
